@echo off
rem ----------------------------------------------------------------
rem Monitoring Agent for CLM Server Monitoring
rem Version 405
rem Windows TEMS Installation Script
rem
rem IBM
rem
rem This file was created by the IBM Tivoli Monitoring Agent Builder
rem Version 6.3.0
rem	IBM Tivoli Monitoring Agent Generator 6.3.0 201302201339
rem	IBM Tivoli Monitoring OSLC Plugin 6.3.0 201302201339
rem	IBM Tivoli Monitoring Agent Builder CIM Data Provider 6.3.0 201302201339
rem	IBM Tivoli Monitoring Agent Builder Custom Data Provider 6.3.0 201302201339
rem	IBM Tivoli Monitoring Agent Builder HTTP Data Provider 6.3.0 201302201339
rem	IBM Tivoli Monitoring Agent Builder ICMP Data Provider 6.3.0 201302201339
rem	IBM Tivoli Monitoring JDBC Data Provider 6.3.0 201302201339
rem	IBM Tivoli Monitoring JMX Data Provider 6.3.0 201302201339
rem	IBM Tivoli Monitoring Agent Builder Log Data Provider 6.3.0 201302201339
rem	IBM Tivoli Monitoring Agent Builder SNMP Data Provider 6.3.0 201302201339
rem	IBM Tivoli Monitoring Agent Builder WMI Data Provider 6.3.0 201302201339
rem	IBM Tivoli Monitoring TMS DLA Plugin 6.3.0 201302201339
rem	IBM Tivoli Monitoring Agent Builder UI 6.3.0 201302201339
rem	IBM Tivoli Monitoring Remote Deploy 6.3.0 201302201339
rem	IBM Tivoli Monitoring Agent Builder Common 6.3.0 201302201339
rem	IBM Tivoli Omnibus 6.3.0 201302201339
rem ----------------------------------------------------------------

setlocal EnableExtensions EnableDelayedExpansion
set errorlevel=
if "%~1" == "" goto usage

if not exist %1 goto nodir

rem installAgentTEMS [ITM installation directory]
rem This program is used by development to install the
rem agent support files into the ITM TEMS runtime environment.
rem There are some manual steps that
rem must be performed after running this script.

rem CANDLE_HOME must be set
set CANDLE_HOME=%~sf1

:processSwitches
@rem With "shift", every argument can be referred to as "%1"
shift
set exit=false

set HAVE_HUBTEMS_HOST=0
set HAVE_HUBTEMS_USER=0
set HAVE_HUBTEMS_PASS=0
:processArg
if "%~1" == "" goto endArgs
if "%~1" == "-e" set exit=true
if "%~1" == "-h" (
    set HUBTEMS_HOST=%2
    set HAVE_HUBTEMS_HOST=1
    shift
)
if "%~1" == "-u" (
    set HUBTEMS_USER=%2
    set HAVE_HUBTEMS_USER=1
    shift
)
if "%~1" == "-p" (
    set HUBTEMS_PASS=%~2
    set HAVE_HUBTEMS_PASS=1
    shift
)
shift
goto processArg

:endArgs

rem if host is provided, we must have a username.  Password will be prompted for if not supplied.
if %HAVE_HUBTEMS_HOST% EQU 1 (
    if %HAVE_HUBTEMS_USER% EQU 0 goto usage
)

rem if we have a user but no host, assume localhost.
if %HAVE_HUBTEMS_USER% EQU 1 (
    if %HAVE_HUBTEMS_HOST% EQU 0 (set HUBTEMS_HOST=localhost& set HAVE_HUBTEMS_HOST=1)
)

if not exist "%CANDLE_HOME%\cms" goto notems

if not exist "%CANDLE_HOME%\logs" mkdir "%CANDLE_HOME%\logs"


set WIN_SHORT_ARCH=WI

rem Check for ver file before parsing it
if not exist "%CANDLE_HOME%\InstallITM\ver\KMS%WIN_SHORT_ARCH%CMS.ver" goto notems
FOR /F "TOKENS=1,2 DELIMS== " %%i IN ('%SYSTEMROOT%\System32\FIND "VRMF=" "%CANDLE_HOME%\InstallITM\ver\KMS%WIN_SHORT_ARCH%CMS.ver"') DO (
    IF %%i==VRMF (SET MSVRMF=%%j)
)
if %MSVRMF% LSS 06210000 (
    echo This agent requires ITM version 06210000 ^(6.2.1^) or higher to work correctly.
    echo The ITM installation in "%CANDLE_HOME%" is version %MSVRMF%,
    echo thus the agent can not install.
    set errorlevel=7
    goto :end
)

rem Determine the TEMS version to see if we can load the support
rem without restarting the TEMS.  This is possible from 6.2FP1 on
if not exist "%CANDLE_HOME%\InstallITM\ver\KMS%WIN_SHORT_ARCH%CMS.ver" goto notems
FOR /F "TOKENS=1,2 DELIMS== " %%i IN ('%SYSTEMROOT%\System32\FIND "VRMF=" "%CANDLE_HOME%\InstallITM\ver\KMSWICMS.ver"') DO (
    IF %%i==VRMF (SET TEMSVRMF=%%j)
)
if %TEMSVRMF% LSS 06200100 (
    if %HAVE_HUBTEMS_HOST% EQU 1 (
        echo Providing login information to load TEMS without restarting is not supported
        echo until ITM 6.2FP1.
        set errorlevel=1
        goto end
    )
    echo ITM version less than 6.2FP1, will recycle TEMS to activate support.
) else (
    if %HAVE_HUBTEMS_HOST% EQU 0 (
        echo No HUB TEMS login information provided, will recycle TEMS to activate support.
    )
)

set TEMS_INSTALL_LOG="%CANDLE_HOME%"\logs\KCDTEMSinstall.log

rem Have to do this outside of main so the Password prompt doesn't go to the log
rem if we weren't passed a password on the command line.
if %TEMSVRMF% GEQ 06200100 (
    if %HAVE_HUBTEMS_HOST% EQU 1 (
        if %HAVE_HUBTEMS_PASS% EQU 1 (
            @echo "%CANDLE_HOME%\bin\tacmd" login -s "%HUBTEMS_HOST%" -u "%HUBTEMS_USER%" -p ******** > %TEMS_INSTALL_LOG%
            @"%CANDLE_HOME%\bin\tacmd" login -s "%HUBTEMS_HOST%" -u "%HUBTEMS_USER%" -p "%HUBTEMS_PASS%"
        ) else (
            @echo "%CANDLE_HOME%\bin\tacmd" login -s "%HUBTEMS_HOST%" -u "%HUBTEMS_USER%" > %TEMS_INSTALL_LOG%
            "%CANDLE_HOME%\bin\tacmd" login -s "%HUBTEMS_HOST%" -u "%HUBTEMS_USER%"
        )
        if errorlevel 1 (
            @echo tacmd login failed with errorlevel %errorlevel% >> %TEMS_INSTALL_LOG%
            set errorlevel=10
            goto end
        ) else (
            @echo tacmd login succeeded. >> %TEMS_INSTALL_LOG%
        )
    ) else (
        @echo No HUB TEMS hostname provided so no tacmd login performed > %TEMS_INSTALL_LOG%
    )
) else (
    @echo TEMS VRMF is %TEMSVRMF% so no tacmd login performed > %TEMS_INSTALL_LOG%
)

rem clear ERRORLEVEL before calling main
cmd /c echo > NUL
call :main >> %TEMS_INSTALL_LOG%
@echo off
if %ERRORLEVEL% EQU 0 (
    echo Install of KCD TEMS Support successful.
) else (
    if %ERRORLEVEL% EQU 10 (
        echo Login to HUB TEMS %HUBTEMS_HOST% failed.
    )
    echo Install of KCD TEMS Support failed.
    echo See %CANDLE_HOME%\logs\KCDTEMSinstall.log for details.
)
goto :eof

:main
@echo on

set KSM_TEMP_DIR=%TEMP%\KCD.%RANDOM%
mkdir %KSM_TEMP_DIR%\TEMS\SQLLIB
mkdir %KSM_TEMP_DIR%\TEMS\ATTRLIB
mkdir %KSM_TEMP_DIR%\TEMS\RKDSCATL
@call :copyFile "ira\agent\common\KCD.atr" "%KSM_TEMP_DIR%\TEMS\ATTRLIB"   &@if errorlevel 1 goto end
@call :copyFile "ira\agent\common\KCD.cat" "%KSM_TEMP_DIR%\TEMS\RKDSCATL"   &@if errorlevel 1 goto end
@call :copyFile "ira\agent\common\ira-kcd.sql" "%KSM_TEMP_DIR%\TEMS\SQLLIB\kcd.sql"   &@if errorlevel 1 goto end
@call :copyFile "ira\agent\common\ira-kcd_del.sql" "%KSM_TEMP_DIR%\TEMS\SQLLIB\kcd_del.sql"   &@if errorlevel 1 goto end
@call :copyFile "ira\agent\common\ira-kcd_upg.sql" "%KSM_TEMP_DIR%\TEMS\SQLLIB\kcd_upg.sql"   &@if errorlevel 1 goto end
@call :copyFile "ira\agent\common\kcd.baroc" "%CANDLE_HOME%\cms\TECLIB\kcd.baroc"   &@if errorlevel 1 goto end

set KSMINST="%CANDLE_HOME%\CMS\ksminst"
rem doesn't matter if TEMS is running for the copy
%KSMINST% -f  -v 610 -e  "%KSM_TEMP_DIR%"

rem TEMS must be running for the seeding to succeed
net start "Tivoli Enterprise Monitoring Svcs - TEMS1"
%KSMINST% -f  -v 610 -s  "%KSM_TEMP_DIR%"
if %ERRORLEVEL% EQU 0 (
   if %TEMSVRMF% GEQ 06200100 (
       if %HAVE_HUBTEMS_HOST% EQU 1 (
           "%CANDLE_HOME%\bin\tacmd" refreshCatalog &@if errorlevel 1 (set errorlevel=11 & goto end)
        ) else (
            call :restartTEMS &@if errorlevel 1 (set errorlevel=12 & goto end)
        )
   ) else (
        call :restartTEMS &@if errorlevel 1 (set errorlevel=12 & goto end)
   )

   @call :copyVerFile KCDWICMS.ver "ira\agent\common\agentConfig\"
   @call :copyFile "ira\agent\common\agentConfig\WIxxx.lvl" "%CANDLE_HOME%\CMS\KCDWICMS.lvl"   &@if errorlevel 1 goto end
) else (
   @echo You must manually add the KCD application support to the TEMS.
)
rem cleanup the temporary directory
rmdir /s /q %KSM_TEMP_DIR%

goto end

:usage
@echo Usage:  installIraAgentTEMS.bat ^<ITM installation directory^> [[-h ^<HUB TEMS hostname^>] -u ^<HUB TEMS username^> [-p ^<HUB TEMS password^>]]
@echo If HUB TEMS and Username are provided but password is not, you will be prompted for the password
goto end

:nodir
@echo The ITM installation directory passed in does not exist.
goto end
:notems
@echo The ITM installation directory passed in does not contain a
@echo Tivoli Enterprise Monitoring Server installation.

:end
@if "%exit%" == "true" exit %errorlevel%
exit /b %errorlevel%
@endlocal
@goto :eof
rem ------------------------------- Subroutines --------------------------------

@rem - Copy a file or set of files in a single directory.
:copyFile
@if exist "%~1" (
    echo copy "%~1" "%~2"
    copy "%~1" "%~2"
) else (
    echo skipping "%~1", does not exist 
    exit /b 0
)
@goto :eof

@rem Copy a version file.  This way kinCinfo.exe knows we are installed.
:copyVerFile
if exist "%CANDLE_HOME%\InstallITM\ver\%~1" (
   rem The ver file is already there
   del %CANDLE_HOME%\InstallITM\ver\%~1
)
rem We need to figure out the date so we can put the install date in the ver file
rem Get the hour separately because we may need to prepend a 0 to it
set hh=%time:~0,2%
rem Since there is no leading zero for times before 10 am, have to put in
rem a zero when this is run before 10 am.
if "%time:~0,1%"==" " set hh=0%hh:~1,1%
set install_date=%date:~10,4%%date:~4,2%%date:~7,2% %hh%%time:~3,2%
rem The install date should now be in the format "YYYYMMDD HHMM"
rem Now, copy the ver file and insert the install date in the right place
for /f "tokens=* eol=" %%L in (%~2\%~1) DO (
   if "%%L"=="[INSTALL INFO]" (
      echo.>>%CANDLE_HOME%\InstallITM\ver\%~1
      echo [INSTALL_INFO]>>%CANDLE_HOME%\InstallITM\ver\%~1
      echo Install Date=%install_date%>>%CANDLE_HOME%\InstallITM\ver\%~1
   ) ELSE (
      set char=%%L
      set char=!char:~0,1!
      if "!char!" == "[" (
         echo.>>%CANDLE_HOME%\InstallITM\ver\%~1
      )
      echo %%L>>%CANDLE_HOME%\InstallITM\ver\%~1
   )
)
@goto :eof


@rem restart the TEMS
:restartTEMS
    net stop "Tivoli Enterprise Monitoring Svcs - TEMS1"
    net start "Tivoli Enterprise Monitoring Svcs - TEMS1"
    @goto :eof
